==> apper_0.7.2.orig.tar.bz2: apper-0.7.2/ApperKCM/TransactionFilterModel.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef TRANSACTION_FILTER_MODEL_H
#define TRANSACTION_FILTER_MODEL_H

#include <QSortFilterProxyModel>

class TransactionFilterModel : public QSortFilterProxyModel
{
    Q_OBJECT
public:
    TransactionFilterModel(QObject *parent = 0);
    ~TransactionFilterModel();

protected:
    bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
};

#endif

==> apper_0.8.1.orig.tar.bz2: apper-0.8.1/ApperKCM/TransactionFilterModel.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef TRANSACTION_FILTER_MODEL_H
#define TRANSACTION_FILTER_MODEL_H

#include <QSortFilterProxyModel>

class TransactionFilterModel : public QSortFilterProxyModel
{
    Q_OBJECT
public:
    explicit TransactionFilterModel(QObject *parent = 0);
    ~TransactionFilterModel();

protected:
    bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
};

#endif
